@@ -40,16 +40,16 @@
 /***************************************************************************/
 /* Basic types */
 
-typedef unsigned char scale2x_uint8;
-typedef unsigned short scale2x_uint16;
-typedef unsigned scale2x_uint32;
+typedef unsigned char scale2x_Uint8;
+typedef unsigned short scale2x_Uint16;
+typedef unsigned scale2x_Uint32;
 
 /***************************************************************************/
 /* Scale2x C implementation */
 
 /* Modified for gngeo: since our src duffer is bigger than dest, we can skip first/last pixel test */
 
-static inline void scale2x_8_def_single(scale2x_uint8* dst, const scale2x_uint8* src0, const scale2x_uint8* src1, const scale2x_uint8* src2, unsigned count)
+static inline void scale2x_8_def_single(scale2x_Uint8* dst, const scale2x_Uint8* src0, const scale2x_Uint8* src1, const scale2x_Uint8* src2, unsigned count)
 {
 	assert(count >= 2);
 #if 0
@@ -93,7 +93,7 @@ static inline void scale2x_8_def_single(scale2x_uint8* dst, const scale2x_uint8*
 #endif
 }
 
-static  inline void scale2x_16_def_single(scale2x_uint16* dst, const scale2x_uint16* src0, const scale2x_uint16* src1, const scale2x_uint16* src2, unsigned count)
+static  inline void scale2x_16_def_single(scale2x_Uint16* dst, const scale2x_Uint16* src0, const scale2x_Uint16* src1, const scale2x_Uint16* src2, unsigned count)
 {
 	assert(count >= 2);
 #if 0
@@ -137,7 +137,7 @@ static  inline void scale2x_16_def_single(scale2x_uint16* dst, const scale2x_uin
 #endif
 }
 
-static  inline void scale2x_32_def_single(scale2x_uint32* dst, const scale2x_uint32* src0, const scale2x_uint32* src1, const scale2x_uint32* src2, unsigned count)
+static  inline void scale2x_32_def_single(scale2x_Uint32* dst, const scale2x_Uint32* src0, const scale2x_Uint32* src1, const scale2x_Uint32* src2, unsigned count)
 {
 	assert(count >= 2);
 #if 0
@@ -194,7 +194,7 @@ static  inline void scale2x_32_def_single(scale2x_uint32* dst, const scale2x_uin
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static inline void scale2x_8_def(scale2x_uint8* dst0, scale2x_uint8* dst1, const scale2x_uint8* src0, const scale2x_uint8* src1, const scale2x_uint8* src2, unsigned count)
+static inline void scale2x_8_def(scale2x_Uint8* dst0, scale2x_Uint8* dst1, const scale2x_Uint8* src0, const scale2x_Uint8* src1, const scale2x_Uint8* src2, unsigned count)
 {
 	assert(count >= 2);
 
@@ -213,7 +213,7 @@ static inline void scale2x_8_def(scale2x_uint8* dst0, scale2x_uint8* dst1, const
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static inline void scale2x_16_def(scale2x_uint16* dst0, scale2x_uint16* dst1, const scale2x_uint16* src0, const scale2x_uint16* src1, const scale2x_uint16* src2, unsigned count)
+static inline void scale2x_16_def(scale2x_Uint16* dst0, scale2x_Uint16* dst1, const scale2x_Uint16* src0, const scale2x_Uint16* src1, const scale2x_Uint16* src2, unsigned count)
 {
 	assert(count >= 2);
 
@@ -232,7 +232,7 @@ static inline void scale2x_16_def(scale2x_uint16* dst0, scale2x_uint16* dst1, co
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static inline void scale2x_32_def(scale2x_uint32* dst0, scale2x_uint32* dst1, const scale2x_uint32* src0, const scale2x_uint32* src1, const scale2x_uint32* src2, unsigned count)
+static inline void scale2x_32_def(scale2x_Uint32* dst0, scale2x_Uint32* dst1, const scale2x_Uint32* src0, const scale2x_Uint32* src1, const scale2x_Uint32* src2, unsigned count)
 {
 	assert(count >= 2);
 
@@ -283,7 +283,7 @@ static inline void scale2x_32_def(scale2x_uint32* dst0, scale2x_uint32* dst1, co
  *      %mm6 -> *current_upper
  *      %mm7 -> *current
  */
-static inline void scale2x_8_mmx_single(scale2x_uint8* dst, const scale2x_uint8* src0, const scale2x_uint8* src1, const scale2x_uint8* src2, unsigned count)
+static inline void scale2x_8_mmx_single(scale2x_Uint8* dst, const scale2x_Uint8* src0, const scale2x_Uint8* src1, const scale2x_Uint8* src2, unsigned count)
 {
 	assert(count >= 16);
 	assert(count % 8 == 0);
@@ -474,7 +474,7 @@ static inline void scale2x_8_mmx_single(scale2x_uint8* dst, const scale2x_uint8*
 	);
 }
 
-static inline void scale2x_16_mmx_single(scale2x_uint16* dst, const scale2x_uint16* src0, const scale2x_uint16* src1, const scale2x_uint16* src2, unsigned count)
+static inline void scale2x_16_mmx_single(scale2x_Uint16* dst, const scale2x_Uint16* src0, const scale2x_Uint16* src1, const scale2x_Uint16* src2, unsigned count)
 {
 	assert(count >= 8);
 	assert(count % 4 == 0);
@@ -665,7 +665,7 @@ static inline void scale2x_16_mmx_single(scale2x_uint16* dst, const scale2x_uint
 	);
 }
 
-static inline void scale2x_32_mmx_single(scale2x_uint32* dst, const scale2x_uint32* src0, const scale2x_uint32* src1, const scale2x_uint32* src2, unsigned count)
+static inline void scale2x_32_mmx_single(scale2x_Uint32* dst, const scale2x_Uint32* src0, const scale2x_Uint32* src1, const scale2x_Uint32* src2, unsigned count)
 {
 	assert(count >= 4);
 	assert(count % 2 == 0);
@@ -877,7 +877,7 @@ static inline void scale2x_32_mmx_single(scale2x_uint32* dst, const scale2x_uint
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static  inline void scale2x_8_mmx(scale2x_uint8* dst0, scale2x_uint8* dst1, const scale2x_uint8* src0, const scale2x_uint8* src1, const scale2x_uint8* src2, unsigned count)
+static  inline void scale2x_8_mmx(scale2x_Uint8* dst0, scale2x_Uint8* dst1, const scale2x_Uint8* src0, const scale2x_Uint8* src1, const scale2x_Uint8* src2, unsigned count)
 {
 	assert(count >= 16);
 	assert(count % 8 == 0);
@@ -897,7 +897,7 @@ static  inline void scale2x_8_mmx(scale2x_uint8* dst0, scale2x_uint8* dst1, cons
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static  inline void scale2x_16_mmx(scale2x_uint16* dst0, scale2x_uint16* dst1, const scale2x_uint16* src0, const scale2x_uint16* src1, const scale2x_uint16* src2, unsigned count)
+static  inline void scale2x_16_mmx(scale2x_Uint16* dst0, scale2x_Uint16* dst1, const scale2x_Uint16* src0, const scale2x_Uint16* src1, const scale2x_Uint16* src2, unsigned count)
 {
 	assert(count >= 8);
 	assert(count % 4 == 0);
@@ -917,7 +917,7 @@ static  inline void scale2x_16_mmx(scale2x_uint16* dst0, scale2x_uint16* dst1, c
  * \param dst0 First destination row, double length in pixels.
  * \param dst1 Second destination row, double length in pixels.
  */
-static  inline void scale2x_32_mmx(scale2x_uint32* dst0, scale2x_uint32* dst1, const scale2x_uint32* src0, const scale2x_uint32* src1, const scale2x_uint32* src2, unsigned count)
+static  inline void scale2x_32_mmx(scale2x_Uint32* dst0, scale2x_Uint32* dst1, const scale2x_Uint32* src0, const scale2x_Uint32* src1, const scale2x_Uint32* src2, unsigned count)
 {
 	assert(count >= 4);
 	assert(count % 2 == 0);
