@@ -19,16 +19,22 @@
 #ifndef _FILEIO_H_
 #define _FILEIO_H_
 
+#include <stdbool.h>
+
 int open_rom(char *romname);
 
-SDL_bool init_game(char *rom_name);
+bool init_game(char *rom_name);
 void open_bios(void);
 void open_conf(void);
 void open_nvram(char *name);
 void save_nvram(char *name);
+void open_memcard(char *name);
+void save_memcard(char *name);
 void list_game(void);
+bool close_game(void);
 
 char *get_gngeo_dir(void);
-
+void chomp(char *str);
+char *my_fgets(char *s, int size, FILE *stream);
 
 #endif
