@@ -1,11 +1,14 @@
 /* Generator is (c) James Ponder, 1997-2001 http://www.squish.net/generator/ */
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "generator.h"
 
 #include "def68k-iibs.h"
 
+//#include "tab68k.c"
+
 /* forward references */
 
 void generate(FILE *output, int topnibble);
