@@ -19,23 +19,28 @@
 #ifndef _TIMER_H_
 #define _TIMER_H_
 
+#include "SDL.h"
 
 typedef struct timer_struct {
     double time;		// when
-    unsigned int odo_debut;
-    unsigned int nb_cycle;
+//	Uint32 time;		// when
+    Uint32 odo_debut;
+    Uint32 nb_cycle;
     int param;
-    unsigned int del_it;
+    Uint32 del_it;
     void (*func) (int param);
     struct timer_struct *next;
 } timer_struct;
 
 extern double timer_count;
+//extern Uint32 timer_count;
 
 timer_struct *insert_timer(double duration, int param, void (*func) (int));
+//timer_struct *insert_timer(Uint32 duration, int param, void (*func) (int));
 void del_timer(timer_struct * ts);
 void my_timer(void);
 double timer_get_time(void);
+//Uint32 timer_get_time(void);
 void free_all_timer(void);
 
 #endif
