@@ -2,13 +2,11 @@
 #define _TRANSPACK_H_
 
 #include "SDL.h"
-
 enum {
-    TILE_UNCONVERTED=0,
-    TILE_NORMAL,
-    TILE_INVISIBLE,
-    TILE_TRANSPARENT25,
-    TILE_TRANSPARENT50
+	TILE_NORMAL,
+	TILE_INVISIBLE,
+	TILE_TRANSPARENT25,
+	TILE_TRANSPARENT50,
 };
 
 typedef struct TRANS_PACK {
@@ -20,5 +18,6 @@ TRANS_PACK *tile_trans;
 
 TRANS_PACK* trans_pack_find(Uint32 tile);
 void trans_pack_open(char *filename);
+void trans_pack_free(void);
 
 #endif
